/*
 * AttributeList.java
 *
 * Created on February 18, 2002, 11:38 AM
 */
import java.util.Vector;
import java.util.Enumeration;
/**
 * This class is used to maintain a list of XMLAttribute objects.
 * It is implemented using a java.util.Vector object.
 *
 * @author  andrewm
 * @version 1.0
 */
public class AttributeList 
{
	// Vector which holds the XML attributes
	private Vector attributes;
	
	/** Creates new AttributeList */
    public AttributeList() 
	{
		attributes = new Vector();
    }

	/**
	 * This method adds an attribute to the attributes Vector
	 *
	 * @param name String representing the name of the attribute
	 * @param value String representing the value of the attribute
	 * @param int ID of the element which contains this attribute
	 * @param String Name of the element which contains this attribute
	 * @param int Path id of this element
	 * @returns int Returns the attribute id
	 */
	public int addAttribute( String name, String value, int elementID, 
								String elementName, int pathID )
	{
		// Create a new XMLAttribute object
		XMLAttribute attribute = new XMLAttribute( name, value, elementID, 
													elementName, pathID );
		
		// Add the object to the attributes vector
		attributes.add( attribute );
		
		// Return the size of the Vector which is the position of the attribute
		// in the vector + 1 to keep the attribute id 1 based.
		return attributes.size();
	}
	
	/**
	 * Returns the list of attributes as an enumeration
	 * 
	 * @return Enumeration Enumeration of the attribute list
	 */
	public Enumeration getElements()
	{
		return attributes.elements();
	}
}
